@@ -48,6 +48,15 @@ print(eval.config.groups(file = config.ini))
 cat("[Debug]:eval.config.groups(file=config.toml)", sep = "\n")
 print(eval.config.groups(file = config.toml))
 
+cat("[Debug]:eval.config.sections(file=config.json)", sep = "\n")
+print(eval.config.sections(file = config.json))
+cat("[Debug]:eval.config.sections(file=config.yaml)", sep = "\n")
+print(eval.config.sections(file = config.yaml))
+cat("[Debug]:eval.config.sections(file=config.ini)", sep = "\n")
+print(eval.config.sections(file = config.ini))
+cat("[Debug]:eval.config.sections(file=config.toml)", sep = "\n")
+print(eval.config.sections(file = config.toml))
+
 cat("[Debug]:eval.config(file = config.json, extra.list = list(debug = 'TRUE'))", sep = "\n")
 print(eval.config(file = config.json, extra.list = list(debug = "TRUE")))
 cat("[Debug]:eval.config(file = config.yaml, extra.list = list(debug = 'TRUE'))", sep = "\n")
